powered by
Function to calculate euclidean distance between two vectors.
myq_euclidean(zm, point = c(1, 2, 1))
Input matrix of set of vectors.
Coordinates of the point to calculate distance to the input.
Sum of the euclidean distance from point to set of vectors.
# NOT RUN { sim.outer(n=1e3, d=3, q.outer=myq_euclidean, point=c(1,1,1)) # }
Run the code above in your browser using DataLab